@@ -36,28 +36,28 @@ void Options5::init()
     m_pOSDPreview->setAlignment( static_cast<OSDWidget::Alignment>( AmarokConfig::osdAlignment() ) );
     m_pOSDPreview->setOffset( AmarokConfig::osdYOffset() );
 
-    connect( m_pOSDPreview, TQT_SIGNAL( positionChanged() ), TQT_SLOT( slotPositionChanged() ) );
+    connect( m_pOSDPreview, TQ_SIGNAL( positionChanged() ), TQ_SLOT( slotPositionChanged() ) );
 
     const int numScreens = TQApplication::desktop()->numScreens();
     for( int i = 0; i < numScreens; i++ )
         kcfg_OsdScreen->insertItem( TQString::number( i ) );
 
-    connect( kcfg_OsdDrawShadow,          TQT_SIGNAL( toggled(bool) ),
-             m_pOSDPreview,               TQT_SLOT( setDrawShadow(bool) ) );
-    connect( kcfg_OsdTextColor,           TQT_SIGNAL( changed(const TQColor&) ),
-             m_pOSDPreview,               TQT_SLOT( setTextColor(const TQColor&) ) );
-    connect( kcfg_OsdUseCustomColors,     TQT_SIGNAL( toggled(bool) ),
-             this,                        TQT_SLOT( useCustomColorsToggled(bool) ) );
-    connect( kcfg_OsdUseFakeTranslucency, TQT_SIGNAL( toggled(bool) ),
-             this,                        TQT_SLOT( useFakeTransparencyToggled(bool) ) );
-    connect( kcfg_OsdBackgroundColor,     TQT_SIGNAL( changed(const TQColor&) ),
-             m_pOSDPreview,               TQT_SLOT( setBackgroundColor(const TQColor&) ) );
-    connect( kcfg_OsdFont,                TQT_SIGNAL( fontSelected(const TQFont&) ),
-             m_pOSDPreview,               TQT_SLOT( setFont(const TQFont&) ) );
-    connect( kcfg_OsdScreen,              TQT_SIGNAL( activated(int) ),
-             m_pOSDPreview,               TQT_SLOT( setScreen(int) ) );
-    connect( kcfg_OsdEnabled,             TQT_SIGNAL( toggled(bool) ),
-             m_pOSDPreview,               TQT_SLOT( setShown(bool) ) );
+    connect( kcfg_OsdDrawShadow,          TQ_SIGNAL( toggled(bool) ),
+             m_pOSDPreview,               TQ_SLOT( setDrawShadow(bool) ) );
+    connect( kcfg_OsdTextColor,           TQ_SIGNAL( changed(const TQColor&) ),
+             m_pOSDPreview,               TQ_SLOT( setTextColor(const TQColor&) ) );
+    connect( kcfg_OsdUseCustomColors,     TQ_SIGNAL( toggled(bool) ),
+             this,                        TQ_SLOT( useCustomColorsToggled(bool) ) );
+    connect( kcfg_OsdUseFakeTranslucency, TQ_SIGNAL( toggled(bool) ),
+             this,                        TQ_SLOT( useFakeTransparencyToggled(bool) ) );
+    connect( kcfg_OsdBackgroundColor,     TQ_SIGNAL( changed(const TQColor&) ),
+             m_pOSDPreview,               TQ_SLOT( setBackgroundColor(const TQColor&) ) );
+    connect( kcfg_OsdFont,                TQ_SIGNAL( fontSelected(const TQFont&) ),
+             m_pOSDPreview,               TQ_SLOT( setFont(const TQFont&) ) );
+    connect( kcfg_OsdScreen,              TQ_SIGNAL( activated(int) ),
+             m_pOSDPreview,               TQ_SLOT( setScreen(int) ) );
+    connect( kcfg_OsdEnabled,             TQ_SIGNAL( toggled(bool) ),
+             m_pOSDPreview,               TQ_SLOT( setShown(bool) ) );
 
     Amarok::QStringx text = i18n(
             "<h3>Tags Displayed in OSD</h3>"
