@@ -15,8 +15,8 @@
 void Options8::updateServices( const TQString &s )
 {
     bool empty = s.isEmpty();
-    groupBox2->setEnabled( !empty );
+    //groupBox2->setEnabled( !empty );
     kcfg_SubmitPlayedSongs->setEnabled( !empty );
-    kcfg_RetrieveSimilarArtists->setEnabled( !empty );
+    //kcfg_RetrieveSimilarArtists->setEnabled( !empty );
 }
 
