@@ -84,7 +84,7 @@ MenuAction::plug( TQWidget *w, int index )
         const int id = TDEAction::getToolButtonID();
 
         addContainer( bar, id );
-        connect( bar, TQT_SIGNAL( destroyed() ), TQT_SLOT( slotDestroyed() ) );
+        connect( bar, TQ_SIGNAL( destroyed() ), TQ_SLOT( slotDestroyed() ) );
 
         //TODO create menu on demand
         //TODO create menu above and aligned within window
@@ -122,7 +122,7 @@ Menu::Menu()
     insertItem( SmallIconSet( Amarok::icon( "covermanager" ) ), i18n( "C&over Manager" ), ID_SHOW_COVER_MANAGER );
     safePlug( ac, "queue_manager", this );
     insertItem( SmallIconSet( Amarok::icon( "visualizations" ) ), i18n( "&Visualizations" ), ID_SHOW_VIS_SELECTOR );
-    insertItem( SmallIconSet( Amarok::icon( "equalizer" ) ), i18n( "E&qualizer" ), kapp, TQT_SLOT( slotConfigEqualizer() ), 0, ID_CONFIGURE_EQUALIZER );
+    insertItem( SmallIconSet( Amarok::icon( "equalizer" ) ), i18n( "E&qualizer" ), kapp, TQ_SLOT( slotConfigEqualizer() ), 0, ID_CONFIGURE_EQUALIZER );
     safePlug( ac, "script_manager", this );
     safePlug( ac, "statistics", this );
 
@@ -154,8 +154,8 @@ Menu::Menu()
 
     safePlug( ac, KStdAction::name(KStdAction::Quit), this );
 
-    connect( this, TQT_SIGNAL( aboutToShow() ),  TQT_SLOT( slotAboutToShow() ) );
-    connect( this, TQT_SIGNAL( activated(int) ), TQT_SLOT( slotActivated(int) ) );
+    connect( this, TQ_SIGNAL( aboutToShow() ),  TQ_SLOT( slotAboutToShow() ) );
+    connect( this, TQ_SIGNAL( activated(int) ), TQ_SLOT( slotActivated(int) ) );
 
     setItemEnabled( ID_SHOW_VIS_SELECTOR, false );
     #ifdef HAVE_LIBVISUAL
@@ -213,7 +213,7 @@ PlayPauseAction::PlayPauseAction( TDEActionCollection *ac )
 {
     engineStateChanged( EngineController::engine()->state() );
 
-    connect( this, TQT_SIGNAL(activated()), EngineController::instance(), TQT_SLOT(playPause()) );
+    connect( this, TQ_SIGNAL(activated()), EngineController::instance(), TQ_SLOT(playPause()) );
 }
 
 void
@@ -277,7 +277,7 @@ AnalyzerAction::plug( TQWidget *w, int index )
         const int id = TDEAction::getToolButtonID();
 
         addContainer( w, id );
-        connect( w, TQT_SIGNAL( destroyed() ), TQT_SLOT( slotDestroyed() ) );
+        connect( w, TQ_SIGNAL( destroyed() ), TQ_SLOT( slotDestroyed() ) );
         TQWidget *container = new AnalyzerContainer( w );
         bar->insertWidget( id, 0, container, index );
         bar->setItemAutoSized( id, true );
@@ -314,7 +314,7 @@ void AnalyzerContainer::changeAnalyzer()
 void
 AnalyzerContainer::mousePressEvent( TQMouseEvent *e)
 {
-    if( e->button() == Qt::LeftButton ) {
+    if( e->button() == TQt::LeftButton ) {
         AmarokConfig::setCurrentPlaylistAnalyzer( AmarokConfig::currentPlaylistAnalyzer() + 1 );
         changeAnalyzer();
     }
@@ -439,8 +439,8 @@ VolumeAction::plug( TQWidget *w, int index )
     TQToolTip::add( m_slider, i18n( "Volume control" ) );
 
     EngineController* const ec = EngineController::instance();
-    connect( m_slider, TQT_SIGNAL(sliderMoved( int )), ec, TQT_SLOT(setVolume( int )) );
-    connect( m_slider, TQT_SIGNAL(sliderReleased( int )), ec, TQT_SLOT(setVolume( int )) );
+    connect( m_slider, TQ_SIGNAL(sliderMoved( int )), ec, TQ_SLOT(setVolume( int )) );
+    connect( m_slider, TQ_SIGNAL(sliderReleased( int )), ec, TQ_SLOT(setVolume( int )) );
 
     static_cast<TDEToolBar*>(w)->insertWidget( TDEAction::getToolButtonID(), 0, m_slider, index );
 
@@ -519,7 +519,7 @@ BurnMenuAction::plug( TQWidget *w, int index )
         const int id = TDEAction::getToolButtonID();
 
         addContainer( bar, id );
-        connect( bar, TQT_SIGNAL( destroyed() ), TQT_SLOT( slotDestroyed() ) );
+        connect( bar, TQ_SIGNAL( destroyed() ), TQ_SLOT( slotDestroyed() ) );
 
         bar->insertButton( TQString(), id, true, i18n( "Burn" ), index );
 
@@ -539,8 +539,8 @@ BurnMenu::BurnMenu()
     insertItem( i18n("Selected Tracks"), SELECTED_TRACKS );
     //TODO add "album" and "all tracks by artist"
 
-    connect( this, TQT_SIGNAL( aboutToShow() ),  TQT_SLOT( slotAboutToShow() ) );
-    connect( this, TQT_SIGNAL( activated(int) ), TQT_SLOT( slotActivated(int) ) );
+    connect( this, TQ_SIGNAL( aboutToShow() ),  TQ_SLOT( slotAboutToShow() ) );
+    connect( this, TQ_SIGNAL( activated(int) ), TQ_SLOT( slotActivated(int) ) );
 }
 
 TDEPopupMenu*
@@ -574,7 +574,7 @@ BurnMenu::slotActivated( int index )
 //////////////////////////////////////////////////////////////////////////////////////////
 
 StopAction::StopAction( TDEActionCollection *ac )
-  : TDEAction( i18n( "Stop" ), Amarok::icon( "stop" ), 0, EngineController::instance(), TQT_SLOT( stop() ), ac, "stop" )
+  : TDEAction( i18n( "Stop" ), Amarok::icon( "stop" ), 0, EngineController::instance(), TQ_SLOT( stop() ), ac, "stop" )
 {}
 
 int
@@ -587,9 +587,9 @@ StopAction::plug( TQWidget *w, int index )
         const int id = TDEAction::getToolButtonID();
 
         addContainer( bar, id );
-        connect( bar, TQT_SIGNAL( destroyed() ), TQT_SLOT( slotDestroyed() ) );
+        connect( bar, TQ_SIGNAL( destroyed() ), TQ_SLOT( slotDestroyed() ) );
 
-        bar->insertButton( TQString(), id, TQT_SIGNAL( clicked() ), EngineController::instance(), TQT_SLOT( stop() ),
+        bar->insertButton( TQString(), id, TQ_SIGNAL( clicked() ), EngineController::instance(), TQ_SLOT( stop() ),
                            true, i18n( "Stop" ), index );
 
         TDEToolBarButton* button = bar->getButton( id );
@@ -610,8 +610,8 @@ StopMenu::StopMenu()
     insertItem( i18n("After Current Track"), AFTER_TRACK );
     insertItem( i18n("After Queue"), AFTER_QUEUE );
 
-    connect( this, TQT_SIGNAL( aboutToShow() ),  TQT_SLOT( slotAboutToShow() ) );
-    connect( this, TQT_SIGNAL( activated(int) ), TQT_SLOT( slotActivated(int) ) );
+    connect( this, TQ_SIGNAL( aboutToShow() ),  TQ_SLOT( slotAboutToShow() ) );
+    connect( this, TQ_SIGNAL( activated(int) ), TQ_SLOT( slotActivated(int) ) );
 }
 
 TDEPopupMenu*
