@@ -60,13 +60,13 @@ CollectionScanner::CollectionScanner( const TQStringList& folders,
         , m_pause( false )
 {
     DcopCollectionScannerHandler* dcsh = new DcopCollectionScannerHandler();
-    connect( dcsh, TQT_SIGNAL(pauseRequest()), this, TQT_SLOT(pause()) );
-    connect( dcsh, TQT_SIGNAL(unpauseRequest()), this, TQT_SLOT(resume()) );
+    connect( dcsh, TQ_SIGNAL(pauseRequest()), this, TQ_SLOT(pause()) );
+    connect( dcsh, TQ_SIGNAL(unpauseRequest()), this, TQ_SLOT(resume()) );
     kapp->setName( TQString( "amarokcollectionscanner" ).ascii() );
     if( !restart )
         TQFile::remove( m_logfile );
 
-    TQTimer::singleShot( 0, this, TQT_SLOT( doJob() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( doJob() ) );
 }
 
 
@@ -108,7 +108,7 @@ CollectionScanner::doJob() //SLOT
             << endl;
         else {
             TQTextStream logStream;
-            logStream.setDevice(TQT_TQIODEVICE(&logFile));
+            logStream.setDevice(&logFile);
             logStream.setEncoding(TQTextStream::UnicodeUTF8);
             lastFile = logStream.read();
             logFile.close();
@@ -120,7 +120,7 @@ CollectionScanner::doJob() //SLOT
             << " read-only" << endl;
         else {
             TQTextStream folderStream;
-            folderStream.setDevice(TQT_TQIODEVICE(&folderFile));
+            folderStream.setDevice(&folderFile);
             folderStream.setEncoding(TQTextStream::UnicodeUTF8);
             entries = TQStringList::split( "\n", folderStream.read() );
         }
