@@ -108,8 +108,8 @@ AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, TDEC
     opt6->setName( "Engine" );
     opt6->setSpacing( KDialog::spacingHint() );
     TQWidget *groupBox, *aboutEngineButton;
-    groupBox            = new TQGroupBox( 2, Qt::Horizontal, i18n("Sound System"), opt6 );
-    m_engineConfigFrame = new TQGroupBox( 1, Qt::Horizontal, opt6 );
+    groupBox            = new TQGroupBox( 2, TQt::Horizontal, i18n("Sound System"), opt6 );
+    m_engineConfigFrame = new TQGroupBox( 1, TQt::Horizontal, opt6 );
     m_soundSystem       = new TQComboBox( false, groupBox );
     aboutEngineButton   = new TQPushButton( i18n("About"), groupBox );
 
@@ -152,7 +152,7 @@ AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, TDEC
     opt9->setSpacing( KDialog::spacingHint() );
     TQVBox *topbox = new TQVBox( opt9 );
     topbox->setSpacing( KDialog::spacingHint() );
-    TQGroupBox *mediaBox  = new TQGroupBox( 2, Qt::Horizontal, i18n("Media Devices"), topbox );
+    TQGroupBox *mediaBox  = new TQGroupBox( 2, TQt::Horizontal, i18n("Media Devices"), topbox );
     mediaBox->setSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Minimum );
     TQVBox *vbox = new TQVBox( mediaBox );
     vbox->setSpacing( KDialog::spacingHint() );
@@ -163,10 +163,10 @@ AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, TDEC
     hbox->setSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Minimum );
     KPushButton *autodetect = new KPushButton( i18n( "Autodetect Devices" ), hbox );
     autodetect->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ) );
-    connect( autodetect, TQT_SIGNAL(clicked()), m_deviceManager, TQT_SLOT(redetectDevices()) );
+    connect( autodetect, TQ_SIGNAL(clicked()), m_deviceManager, TQ_SLOT(redetectDevices()) );
     KPushButton *add = new KPushButton( i18n( "Add Device..." ), hbox );
     add->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ) );
-    connect( add, TQT_SIGNAL(clicked()), m_deviceManager, TQT_SLOT(newDevice()) );
+    connect( add, TQ_SIGNAL(clicked()), m_deviceManager, TQ_SLOT(newDevice()) );
 
     TQFrame *frame = new TQFrame( topbox );
     frame->setSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding );
@@ -184,28 +184,28 @@ AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, TDEC
     addPage( opt9,   i18n( "Media Devices" ), Amarok::icon( "device" ), i18n( "Configure Portable Player Support" ) );
 
     // Show information labels (must be done after insertions)
-    TQObjectList *list = queryList( TQLABEL_OBJECT_NAME_STRING, "infoPixmap" );
+    TQObjectList *list = queryList( "TQLabel", "infoPixmap" );
     TQPixmap const info = TDEGlobal::iconLoader()->iconPath( "messagebox_info", -TDEIcon::SizeHuge );
     for( TQObject *label = list->first(); label; label = list->next() )
-        static_cast<TQLabel*>(TQT_TQWIDGET(label))->setPixmap( info );
+        static_cast<TQLabel*>(label)->setPixmap( info );
     delete list;
 
     //stop TDEFont Requesters getting stupidly large
-    list = queryList( TQLABEL_OBJECT_NAME_STRING, "m_sampleLabel" );
+    list = queryList( "TQLabel", "m_sampleLabel" );
     for( TQObject *label = list->first(); label; label = list->next() )
-        static_cast<TQLabel*>(TQT_TQWIDGET(label))->setMaximumWidth( 250 );
+        static_cast<TQLabel*>(label)->setMaximumWidth( 250 );
     delete list;
 
-    connect( m_deviceManager, TQT_SIGNAL(changed()), TQT_SLOT(updateButtons()) );
-    connect( m_soundSystem, TQT_SIGNAL(activated( int )), TQT_SLOT(updateButtons()) );
-    connect( aboutEngineButton, TQT_SIGNAL(clicked()), TQT_SLOT(aboutEngine()) );
+    connect( m_deviceManager, TQ_SIGNAL(changed()), TQ_SLOT(updateButtons()) );
+    connect( m_soundSystem, TQ_SIGNAL(activated( int )), TQ_SLOT(updateButtons()) );
+    connect( aboutEngineButton, TQ_SIGNAL(clicked()), TQ_SLOT(aboutEngine()) );
 #ifdef TQ_WS_X11
-    connect( opt5, TQT_SIGNAL(settingsChanged()), TQT_SLOT(updateButtons()) ); //see options5.ui.h
+    connect( opt5, TQ_SIGNAL(settingsChanged()), TQ_SLOT(updateButtons()) ); //see options5.ui.h
 #endif
-    connect( m_opt2->styleComboBox, TQT_SIGNAL( activated( int ) ), TQT_SLOT( updateButtons() ) );
-    connect( m_opt7->dbSetupFrame->databaseEngine, TQT_SIGNAL( activated( int ) ), TQT_SLOT( updateButtons() ) );
-    connect( m_opt1->kComboBox_browser, TQT_SIGNAL( activated( int ) ), TQT_SLOT( updateButtons() ) );
-    connect( m_opt1->kLineEdit_customBrowser, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( updateButtons() ) );
+    connect( m_opt2->styleComboBox, TQ_SIGNAL( activated( int ) ), TQ_SLOT( updateButtons() ) );
+    connect( m_opt7->dbSetupFrame->databaseEngine, TQ_SIGNAL( activated( int ) ), TQ_SLOT( updateButtons() ) );
+    connect( m_opt1->kComboBox_browser, TQ_SIGNAL( activated( int ) ), TQ_SLOT( updateButtons() ) );
+    connect( m_opt1->kLineEdit_customBrowser, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SLOT( updateButtons() ) );
 }
 
 AmarokConfigDialog::~AmarokConfigDialog()
@@ -263,13 +263,13 @@ void AmarokConfigDialog::updateButtons()
 void AmarokConfigDialog::updateSettings()
 {
 #ifdef TQ_WS_X11
-    OSDPreviewWidget *osd = static_cast<OSDPreviewWidget*>( TQT_TQWIDGET(child( "osdpreview" )) );
+    OSDPreviewWidget *osd = static_cast<OSDPreviewWidget*>( child( "osdpreview" ) );
     AmarokConfig::setOsdAlignment( osd->alignment() );
     AmarokConfig::setOsdYOffset( osd->y() );
     Amarok::OSD::instance()->applySettings();
 #endif
 
-    static_cast<CollectionSetup*>(TQT_TQWIDGET(child("CollectionSetup")))->writeConfig();
+    static_cast<CollectionSetup*>(child("CollectionSetup"))->writeConfig();
 
     if ( m_engineConfig ) m_engineConfig->save();
 
@@ -300,8 +300,8 @@ void AmarokConfigDialog::updateSettings()
     {
         PlaylistWindow::self()->addBrowser( "MediaBrowser", MediaBrowser::instance(), i18n( "Media Device" ), Amarok::icon( "device" ) );
         //to re-enable mediabrowser hiding, uncomment this:
-        //connect( MediaBrowser::instance(), TQT_SIGNAL( availabilityChanged( bool ) ),
-        //         PlaylistWindow::self(), TQT_SLOT( mbAvailabilityChanged( bool ) ) );
+        //connect( MediaBrowser::instance(), TQ_SIGNAL( availabilityChanged( bool ) ),
+        //         PlaylistWindow::self(), TQ_SLOT( mbAvailabilityChanged( bool ) ) );
 
     }
 
@@ -352,7 +352,7 @@ void AmarokConfigDialog::updateWidgetsDefault()
 bool AmarokConfigDialog::hasChanged()
 {
 #ifdef TQ_WS_X11
-    OSDPreviewWidget *osd = static_cast<OSDPreviewWidget*>( TQT_TQWIDGET(child( "osdpreview" )) );
+    OSDPreviewWidget *osd = static_cast<OSDPreviewWidget*>( child( "osdpreview" ) );
 #endif
 
     return  m_soundSystem->currentText() != m_pluginAmarokName[AmarokConfig::soundSystem()] ||
@@ -410,7 +410,7 @@ void AmarokConfigDialog::soundSystemChanged()
         m_engineConfigFrame->setTitle( i18n( "to change settings", "Configure %1" ).arg( m_soundSystem->currentText() ) );
         m_engineConfigFrame->show();
 
-        connect( m_engineConfig, TQT_SIGNAL(viewChanged()), TQT_SLOT(updateButtons()) );
+        connect( m_engineConfig, TQ_SIGNAL(viewChanged()), TQ_SLOT(updateButtons()) );
     }
     else {
         m_engineConfig = 0;
