@@ -43,7 +43,7 @@ class DbConnectionPool : TQPtrQueue<DbConnection>
 
 class CollectionDB : public TQObject, public EngineObserver
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     friend class SimilarArtistsInsertionJob;
