@@ -168,7 +168,7 @@ typedef LONG32  HX_RESULT;
 #define HXR_AUTH_TCP_CONNECT_FAILURE    MAKE_HX_RESULT(1,SS_NET,36)                 // 80040064
 #define HXR_AUTH_TCP_CONNECT_TIMEOUT    MAKE_HX_RESULT(1,SS_NET,37)                 // 80040065
 #define HXR_AUTH_FAILURE                MAKE_HX_RESULT(1,SS_NET,38)                 // 80040066
-#define HXR_AUTH_RETQ_PARAMETER_MISSING  MAKE_HX_RESULT(1,SS_NET,39)                 // 80040067
+#define HXR_AUTH_REQ_PARAMETER_MISSING  MAKE_HX_RESULT(1,SS_NET,39)                 // 80040067
 #define HXR_DNS_RESOLVE_FAILURE         MAKE_HX_RESULT(1,SS_NET,40)                 // 80040068
 #define HXR_AUTH_SUCCEEDED              MAKE_HX_RESULT(0,SS_NET,40)                 // 00040068
 #define HXR_PULL_AUTHENTICATION_FAILED  MAKE_HX_RESULT(1,SS_NET,41)                 // 80040069
