@@ -36,7 +36,7 @@ namespace KDE { namespace Multimedia { class SimplePlayer; } }
 
 class KDEMMEngine : public Engine::Base
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
