@@ -31,7 +31,7 @@ class HostListItem;
 
 class HostList : public TDEListView
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
