@@ -30,7 +30,7 @@ XineGeneralEntry::XineGeneralEntry(const TQString& key, xine_t *xine, XineConfig
     , m_xine(xine)
 {
     debug() << "new entry " << m_key << endl;
-    connect(this, TQT_SIGNAL(viewChanged()), xcf, TQT_SIGNAL(viewChanged() ) );
+    connect(this, TQ_SIGNAL(viewChanged()), xcf, TQ_SIGNAL(viewChanged() ) );
 }
 
 
@@ -85,7 +85,7 @@ XineStrEntry::XineStrEntry(TQLineEdit* input, const TQCString & key, xine_t *xin
         input->setText(ent.str_value);
         m_val = ent.str_value;
     }
-     connect( input, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( entryChanged(const TQString &) ) );
+     connect( input, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( entryChanged(const TQString &) ) );
 }
 
 
@@ -117,7 +117,7 @@ XineIntEntry::XineIntEntry(KIntSpinBox* input, const TQCString & key, xine_t *xi
             input->setValue(ent.num_value);
             m_val = ent.num_value;
         }
-     connect( input,  TQT_SIGNAL( valueChanged( int ) ), this, TQT_SLOT( entryChanged( int ) ) );
+     connect( input,  TQ_SIGNAL( valueChanged( int ) ), this, TQ_SLOT( entryChanged( int ) ) );
 }
 
 
@@ -159,7 +159,7 @@ XineEnumEntry::XineEnumEntry(TQComboBox* input, const TQCString & key, xine_t *x
         input->setCurrentItem( ent.num_value );
         m_val = ent.num_value;
     }
-     connect( input,  TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( entryChanged( int ) ) );
+     connect( input,  TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( entryChanged( int ) ) );
 }
 
 ///////////////////////
@@ -181,7 +181,7 @@ XineConfigDialog::XineConfigDialog( const xine_t* const xine)
             m_view->deviceComboBox->insertItem(drivers[i]);
     }
 
-    connect( m_view->deviceComboBox, TQT_SIGNAL( activated( int ) ), TQT_SIGNAL( viewChanged() ) );
+    connect( m_view->deviceComboBox, TQ_SIGNAL( activated( int ) ), TQ_SIGNAL( viewChanged() ) );
     m_entries.setAutoDelete(true);
     m_view->deviceComboBox->setCurrentItem( (XineCfg::outputPlugin() == "auto" ) ? "Autodetect" : XineCfg::outputPlugin() );
     init();
