@@ -24,7 +24,7 @@ class XineConfigDialog;
 
 class XineEngine : public Engine::Base
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     friend class Fader;
@@ -53,7 +53,10 @@ class XineEngine : public Engine::Base
     virtual Amarok::PluginConfig *configure() const;
     virtual void setEqualizerEnabled( bool );
     virtual void setEqualizerParameters( int preamp, const TQValueList<int>& );
+    virtual void setVolume( uint value );
     virtual void setVolumeSW( uint );
+    static  uint adjustVolume( uint volume );
+
     virtual void fadeOut( uint fadeLength, bool* terminate, bool exiting = false );
 
     static  void XineEventListener( void*, const xine_event_t* );
@@ -80,6 +83,7 @@ class XineEngine : public Engine::Base
     int64_t             m_currentVpts;
     float               m_preamp;
 
+    static bool         s_logarithmicVolume;
     bool                m_stopFader;
     bool                m_fadeOutRunning;
 
