@@ -15,7 +15,7 @@ copyright            : (C) 2006 by Sascha Sommer <saschasommer@freenet.de>
 
 #include <tqapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <iostream>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -47,7 +47,7 @@ signal_handler( DBusConnection * /*con*/, DBusMessage *msg, void *data )
     const char *interface   = dbus_message_get_interface(msg);
     bool        handled     = true;
 
-    debug() << "TQT_SIGNAL member " << member << " interface " << interface  << " objpath " << objectpath << endl;
+    debug() << "TQ_SIGNAL member " << member << " interface " << interface  << " objpath " << objectpath << endl;
 
     if (dbus_message_is_signal( msg, "org.yauap.CommandInterface", "MetadataSignal")) 
        TQApplication::postEvent(engine, new TQCustomEvent(3004));
@@ -397,7 +397,7 @@ yauapEngine::initDbusConnection()
     helper.clearArguments();
     helper << "yauap" << "-noexit";
 
-    if( !helper.start(KProcess::NotifyOnExit, KProcess::All))
+    if( !helper.start(TDEProcess::NotifyOnExit, TDEProcess::All))
     {
         debug() << "could not start yauap " << endl;
         emit statusText( i18n( "could not start yauap" ) );
@@ -473,7 +473,7 @@ yauapEngine::init()
 
     m_state = Engine::Idle;
 
-    connect(&helper, TQT_SIGNAL(processExited(KProcess*)), TQT_SLOT(yauapProcessExited()));
+    connect(&helper, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SLOT(yauapProcessExited()));
 
     if (initDbusConnection())
         return true;
