@@ -60,7 +60,7 @@ namespace Engine
 
     class LIBAMAROK_EXPORT Base : public TQObject, public Amarok::Plugin
     {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     signals:
@@ -179,7 +179,7 @@ namespace Engine
          * Set new volume value.
          * @param value Volume in range 0 to 100.
          */
-        void setVolume( uint value );
+        virtual void setVolume( uint value );
 
         /** Set new crossfade length (msec) */
         void setXfadeLength( int value ) { m_xfadeLength = value; }
