@@ -29,11 +29,11 @@
 #include <tqobjectlist.h>
 #include <tqtimer.h>
 
-#include <kapplication.h>
-#include <kfileitem.h>
-#include <kio/global.h>
-#include <kio/job.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdefileitem.h>
+#include <tdeio/global.h>
+#include <tdeio/job.h>
+#include <tdemessagebox.h>
 #include <krun.h>
 
 #include <cstdlib>
@@ -67,7 +67,7 @@ EngineController::EngineController()
 {
     m_voidEngine = m_engine = loadEngine( "void-engine" );
 
-    connect( m_timer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotMainTimer() ) );
+    connect( m_timer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotMainTimer() ) );
 }
 
 EngineController::~EngineController()
@@ -113,7 +113,7 @@ EngineController::loadEngine() //static
 
     m_engine = loadEngine( AmarokConfig::soundSystem() );
 
-    const TQString engineName = PluginManager::getService( m_engine )->property( "X-KDE-Amarok-name" ).toString();
+    const TQString engineName = PluginManager::getService( m_engine )->property( "X-TDE-Amarok-name" ).toString();
 
     if( !AmarokConfig::soundSystem().isEmpty() && engineName != AmarokConfig::soundSystem() ) {
         //AmarokConfig::soundSystem() is empty on the first-ever-run
@@ -142,11 +142,11 @@ EngineController::loadEngine( const TQString &engineName )
 
     DEBUG_BLOCK
 
-    TQString query = "[X-KDE-Amarok-plugintype] == 'engine' and [X-KDE-Amarok-name] != '%1'";
-    KTrader::OfferList offers = PluginManager::query( query.arg( engineName ) );
+    TQString query = "[X-TDE-Amarok-plugintype] == 'engine' and [X-TDE-Amarok-name] != '%1'";
+    TDETrader::OfferList offers = PluginManager::query( query.arg( engineName ) );
 
     // sort by rank, TQValueList::operator[] is O(n), so this is quite inefficient
-    #define rank( x ) (x)->property( "X-KDE-Amarok-rank" ).toInt()
+    #define rank( x ) (x)->property( "X-TDE-Amarok-rank" ).toInt()
     for( int n = offers.count()-1, i = 0; i < n; i++ )
         for( int j = n; j > i; j-- )
             if( rank( offers[j] ) > rank( offers[j-1] ) )
@@ -154,31 +154,31 @@ EngineController::loadEngine( const TQString &engineName )
     #undef rank
 
     // this is the actual engine we want
-    query = "[X-KDE-Amarok-plugintype] == 'engine' and [X-KDE-Amarok-name] == '%1'";
+    query = "[X-TDE-Amarok-plugintype] == 'engine' and [X-TDE-Amarok-name] == '%1'";
     offers = PluginManager::query( query.arg( engineName ) ) + offers;
 
-    foreachType( KTrader::OfferList, offers ) {
+    foreachType( TDETrader::OfferList, offers ) {
         Amarok::Plugin *plugin = PluginManager::createFromService( *it );
 
         if( plugin ) {
-            TQObject *bar = TQT_TQOBJECT(Amarok::StatusBar::instance());
+            TQObject *bar = Amarok::StatusBar::instance();
             EngineBase *engine = static_cast<EngineBase*>( plugin );
 
-            connect( engine, TQT_SIGNAL(stateChanged( Engine::State )),
-                       this,   TQT_SLOT(slotStateChanged( Engine::State )) );
-            connect( engine, TQT_SIGNAL(trackEnded()),
-                       this,   TQT_SLOT(slotTrackEnded()) );
+            connect( engine, TQ_SIGNAL(stateChanged( Engine::State )),
+                       this,   TQ_SLOT(slotStateChanged( Engine::State )) );
+            connect( engine, TQ_SIGNAL(trackEnded()),
+                       this,   TQ_SLOT(slotTrackEnded()) );
             if( bar )
             {
-                connect( engine, TQT_SIGNAL(statusText( const TQString& )),
-                            bar,   TQT_SLOT(shortMessage( const TQString& )) );
-                connect( engine, TQT_SIGNAL(infoMessage( const TQString& )),
-                            bar,   TQT_SLOT(longMessage( const TQString& )) );
+                connect( engine, TQ_SIGNAL(statusText( const TQString& )),
+                            bar,   TQ_SLOT(shortMessage( const TQString& )) );
+                connect( engine, TQ_SIGNAL(infoMessage( const TQString& )),
+                            bar,   TQ_SLOT(longMessage( const TQString& )) );
             }
-            connect( engine, TQT_SIGNAL(metaData( const Engine::SimpleMetaBundle& )),
-                       this,   TQT_SLOT(slotEngineMetaData( const Engine::SimpleMetaBundle& )) );
-            connect( engine, TQT_SIGNAL(showConfigDialog( const TQCString& )),
-                       kapp,   TQT_SLOT(slotConfigAmarok( const TQCString& )) );
+            connect( engine, TQ_SIGNAL(metaData( const Engine::SimpleMetaBundle& )),
+                       this,   TQ_SLOT(slotEngineMetaData( const Engine::SimpleMetaBundle& )) );
+            connect( engine, TQ_SIGNAL(showConfigDialog( const TQCString& )),
+                       kapp,   TQ_SLOT(slotConfigAmarok( const TQCString& )) );
 
             if( engine->init() )
                 return engine;
@@ -187,17 +187,17 @@ EngineController::loadEngine( const TQString &engineName )
         }
     }
 
-    KRun::runCommand( "kbuildsycoca" );
+    KRun::runCommand( "tdebuildsycoca" );
 
     KMessageBox::error( 0, i18n(
             "<p>Amarok could not find any sound-engine plugins. "
-            "Amarok is now updating the KDE configuration database. Please wait a couple of minutes, then restart Amarok.</p>"
+            "Amarok is now updating the TDE configuration database. Please wait a couple of minutes, then restart Amarok.</p>"
             "<p>If this does not help, "
             "it is likely that Amarok is installed under the wrong prefix, please fix your installation using:<pre>"
             "$ cd /path/to/amarok/source-code/<br>"
             "$ su -c \"make uninstall\"<br>"
-            "$ ./configure --prefix=`kde-config --prefix` && su -c \"make install\"<br>"
-            "$ kbuildsycoca<br>"
+            "$ ./configure --prefix=`tde-config --prefix` && su -c \"make install\"<br>"
+            "$ tdebuildsycoca<br>"
             "$ amarok</pre>"
             "More information can be found in the README file. For further assistance join us at #amarok on irc.freenode.net.</p>" ) );
 
@@ -270,8 +270,8 @@ void EngineController::unplayableNotification() {
 
 bool EngineController::installDistroCodec( const TQString& engine /*Filetype type*/)
 {
-    KService::Ptr service = KTrader::self()->query( "Amarok/CodecInstall"
-        , TQString("[X-KDE-Amarok-codec] == 'mp3' and [X-KDE-Amarok-engine] == '%1'").arg(engine) ).first();
+    KService::Ptr service = TDETrader::self()->query( "Amarok/CodecInstall"
+        , TQString("[X-TDE-Amarok-codec] == 'mp3' and [X-TDE-Amarok-engine] == '%1'").arg(engine) ).first();
     if( service )
     {
         TQString installScript = service->exec();
@@ -392,7 +392,7 @@ void EngineController::play( const MetaBundle &bundle, uint offset )
 
     // WebDAV protocol is HTTP with extensions (and the "webdav" scheme
     // is a KDE-ism anyway). Most engines cope with HTTP streaming, but
-    // not through KIO, so they don't support KDE-isms.
+    // not through TDEIO, so they don't support KDE-isms.
     if ( url.protocol() == "webdav" )
         url.setProtocol( "http" );
     else if ( url.protocol() == "webdavs" )
@@ -406,10 +406,10 @@ void EngineController::play( const MetaBundle &bundle, uint offset )
             if (LastFm::Controller::instance()->changeStation( url.url() ) == -1)
                 // Request was canceled, return immediately.
                 return;
-            connect( m_engine, TQT_SIGNAL( lastFmTrackChange() ), LastFm::Controller::instance()->getService()
-            , TQT_SLOT( requestMetaData() ) );
-            connect( LastFm::Controller::instance()->getService(), TQT_SIGNAL( metaDataResult( const MetaBundle& ) ),
-                     this, TQT_SLOT( slotStreamMetaData( const MetaBundle& ) ) );
+            connect( m_engine, TQ_SIGNAL( lastFmTrackChange() ), LastFm::Controller::instance()->getService()
+            , TQ_SLOT( requestMetaData() ) );
+            connect( LastFm::Controller::instance()->getService(), TQ_SIGNAL( metaDataResult( const MetaBundle& ) ),
+                     this, TQ_SLOT( slotStreamMetaData( const MetaBundle& ) ) );
             return;
         }
         else
@@ -422,10 +422,10 @@ void EngineController::play( const MetaBundle &bundle, uint offset )
                 return;
 
             m_lastFm = true;
-            connect( m_engine, TQT_SIGNAL( lastFmTrackChange() ), LastFm::Controller::instance()->getService()
-                    , TQT_SLOT( requestMetaData() ) );
-            connect( LastFm::Controller::instance()->getService(), TQT_SIGNAL( metaDataResult( const MetaBundle& ) ),
-                    this, TQT_SLOT( slotStreamMetaData( const MetaBundle& ) ) );
+            connect( m_engine, TQ_SIGNAL( lastFmTrackChange() ), LastFm::Controller::instance()->getService()
+                    , TQ_SLOT( requestMetaData() ) );
+            connect( LastFm::Controller::instance()->getService(), TQ_SIGNAL( metaDataResult( const MetaBundle& ) ),
+                    this, TQ_SLOT( slotStreamMetaData( const MetaBundle& ) ) );
         }
         debug() << "New URL is " << url.url() << endl;
     }
@@ -500,7 +500,7 @@ void EngineController::play( const MetaBundle &bundle, uint offset )
            {
                //False gives behaviour as if track played successfully
                next( false );
-               TQTimer::singleShot( 0, this, TQT_SLOT(play()) );
+               TQTimer::singleShot( 0, this, TQ_SLOT(play()) );
            }
            else
            {
@@ -747,7 +747,7 @@ void EngineController::slotTrackEnded() //SLOT
         //FIXME not perfect
         if ( !m_isTiming )
         {
-            TQTimer::singleShot( AmarokConfig::trackDelayLength(), this, TQT_SLOT(trackFinished()) );
+            TQTimer::singleShot( AmarokConfig::trackDelayLength(), this, TQ_SLOT(trackFinished()) );
             m_isTiming = true;
         }
 
