@@ -40,7 +40,7 @@ namespace TDEIO { class Job; }
    DO NOT use this class for anything else, use TDEIO directly instead. */
 class AmarokHttp : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
@@ -74,7 +74,7 @@ namespace LastFm
 
     class Controller : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
   
 
         public:
@@ -110,7 +110,7 @@ namespace LastFm
 
     class WebService : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
   
 
         public:
@@ -272,7 +272,7 @@ namespace LastFm
 
     class LoginDialog : public KDialogBase
     {
-        Q_OBJECT
+        TQ_OBJECT
   
 
         public:
@@ -289,7 +289,7 @@ namespace LastFm
 
     class CustomStationDialog : public KDialogBase
     {
-        Q_OBJECT
+        TQ_OBJECT
   
 
         public:
