@@ -51,11 +51,11 @@ void MagnatuneAlbumDownloader::downloadAlbum( MagnatuneDownloadInfo * info )
 
     m_albumDownloadJob = TDEIO::file_copy( downloadUrl, KURL( m_tempDir.name() + m_currentAlbumFileName ), -1, true, false, false );
 
-    connect( m_albumDownloadJob, TQT_SIGNAL( result( TDEIO::Job* ) ), TQT_SLOT( albumDownloadComplete( TDEIO::Job* ) ) );
+    connect( m_albumDownloadJob, TQ_SIGNAL( result( TDEIO::Job* ) ), TQ_SLOT( albumDownloadComplete( TDEIO::Job* ) ) );
 
     Amarok::StatusBar::instance() ->newProgressOperation( m_albumDownloadJob )
     .setDescription( i18n( "Downloading album" ) )
-    .setAbortSlot( this, TQT_SLOT( albumDownloadAborted() ) );
+    .setAbortSlot( this, TQ_SLOT( albumDownloadAborted() ) );
 }
 
 void MagnatuneAlbumDownloader::downloadCover( TQString albumCoverUrlString, TQString fileName )
@@ -66,11 +66,11 @@ void MagnatuneAlbumDownloader::downloadCover( TQString albumCoverUrlString, TQSt
 
     m_albumDownloadJob = TDEIO::file_copy( downloadUrl, KURL( m_tempDir.name() + fileName ), -1, true, false, false );
 
-    connect( m_albumDownloadJob, TQT_SIGNAL( result( TDEIO::Job* ) ), TQT_SLOT( coverDownloadComplete( TDEIO::Job* ) ) );
+    connect( m_albumDownloadJob, TQ_SIGNAL( result( TDEIO::Job* ) ), TQ_SLOT( coverDownloadComplete( TDEIO::Job* ) ) );
 
     Amarok::StatusBar::instance() ->newProgressOperation( m_albumDownloadJob )
     .setDescription( i18n( "Downloading album cover" ) )
-    .setAbortSlot( this, TQT_SLOT( coverDownloadAborted() ) );
+    .setAbortSlot( this, TQ_SLOT( coverDownloadAborted() ) );
 }
 
 
@@ -117,11 +117,11 @@ void MagnatuneAlbumDownloader::albumDownloadComplete( TDEIO::Job * downloadJob )
 
         m_albumDownloadJob = TDEIO::file_copy( downloadUrl, KURL( finalAlbumPath + "/cover.jpg" ), -1, true, false, false );
 
-        connect( m_albumDownloadJob, TQT_SIGNAL( result( TDEIO::Job* ) ), TQT_SLOT( coverAddComplete( TDEIO::Job* ) ) );
+        connect( m_albumDownloadJob, TQ_SIGNAL( result( TDEIO::Job* ) ), TQ_SLOT( coverAddComplete( TDEIO::Job* ) ) );
 
         Amarok::StatusBar::instance() ->newProgressOperation( m_albumDownloadJob )
         .setDescription( i18n( "Adding album cover to collection" ) )
-        .setAbortSlot( this, TQT_SLOT( coverAddAborted() ) );
+        .setAbortSlot( this, TQ_SLOT( coverAddAborted() ) );
 
     } else {
 
