@@ -27,7 +27,7 @@
 
 class MagnatuneRedownloadDialog : public magnatuneReDownloadDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
