@@ -58,8 +58,8 @@ void MagnatuneRedownloadHandler::showRedownloadDialog( )
 
     if (m_redownloadDialog == 0) {
         m_redownloadDialog = new MagnatuneRedownloadDialog( m_parent );
-        connect( m_redownloadDialog, TQT_SIGNAL( redownload( TQString) ), this, TQT_SLOT( redownload( TQString ) ) );
-        connect( m_redownloadDialog, TQT_SIGNAL(cancelled() ), this, TQT_SLOT( selectionDialogCancelled() ));
+        connect( m_redownloadDialog, TQ_SIGNAL( redownload( TQString) ), this, TQ_SLOT( redownload( TQString ) ) );
+        connect( m_redownloadDialog, TQ_SIGNAL(cancelled() ), this, TQ_SLOT( selectionDialogCancelled() ));
     }
 
 
@@ -102,13 +102,13 @@ void MagnatuneRedownloadHandler::redownload( TQString storedInfoFileName )
     if ( m_albumDownloader == 0 )
     {
         m_albumDownloader = new MagnatuneAlbumDownloader();
-        connect( m_albumDownloader, TQT_SIGNAL( downloadComplete( bool ) ), this, TQT_SLOT( albumDownloadComplete( bool ) ) );
+        connect( m_albumDownloader, TQ_SIGNAL( downloadComplete( bool ) ), this, TQ_SLOT( albumDownloadComplete( bool ) ) );
     }
 
 
     if (m_downloadDialog == 0) {
         m_downloadDialog = new MagnatuneDownloadDialog(m_parent);
-         connect( m_downloadDialog, TQT_SIGNAL( downloadAlbum( MagnatuneDownloadInfo *  ) ), m_albumDownloader, TQT_SLOT( downloadAlbum( MagnatuneDownloadInfo * ) ) );
+         connect( m_downloadDialog, TQ_SIGNAL( downloadAlbum( MagnatuneDownloadInfo *  ) ), m_albumDownloader, TQ_SLOT( downloadAlbum( MagnatuneDownloadInfo * ) ) );
     }
 
 
