@@ -162,8 +162,8 @@ void
 Reader::logoutRequest()
 {
     ContentFetcher* http = new ContentFetcher( m_host, m_port, m_password, this, "readerLogoutHttp" );
-    connect( http, TQT_SIGNAL( httpError( const TQString& ) ), this, TQT_SLOT( fetchingError( const TQString& ) ) );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( logoutRequest( int, bool ) ) );
+    connect( http, TQ_SIGNAL( httpError( const TQString& ) ), this, TQ_SLOT( fetchingError( const TQString& ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( logoutRequest( int, bool ) ) );
     http->getDaap( "/logout?" + m_loginString );
 }
 
@@ -179,9 +179,9 @@ Reader::loginRequest()
 {
     DEBUG_BLOCK
     ContentFetcher* http = new ContentFetcher( m_host, m_port, m_password, this, "readerHttp");
-    connect( http, TQT_SIGNAL( httpError( const TQString& ) ), this, TQT_SLOT( fetchingError( const TQString& ) ) );
-    connect( http, TQT_SIGNAL(  responseHeaderReceived( const TQHttpResponseHeader & ) )
-            , this, TQT_SLOT( loginHeaderReceived( const TQHttpResponseHeader & ) ) );
+    connect( http, TQ_SIGNAL( httpError( const TQString& ) ), this, TQ_SLOT( fetchingError( const TQString& ) ) );
+    connect( http, TQ_SIGNAL(  responseHeaderReceived( const TQHttpResponseHeader & ) )
+            , this, TQ_SLOT( loginHeaderReceived( const TQHttpResponseHeader & ) ) );
     http->getDaap( "/login" );
 }
 
@@ -190,15 +190,15 @@ Reader::loginHeaderReceived( const TQHttpResponseHeader & resp )
 {
     DEBUG_BLOCK
     ContentFetcher* http = (ContentFetcher*) sender();
-    disconnect( http, TQT_SIGNAL(  responseHeaderReceived( const TQHttpResponseHeader & ) )
-            , this, TQT_SLOT( loginHeaderReceived( const TQHttpResponseHeader & ) ) );
+    disconnect( http, TQ_SIGNAL(  responseHeaderReceived( const TQHttpResponseHeader & ) )
+            , this, TQ_SLOT( loginHeaderReceived( const TQHttpResponseHeader & ) ) );
     if( resp.statusCode() == 401 /*authorization required*/)
     {
         emit passwordRequired();
         http->deleteLater();
         return;
     }
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( loginFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( loginFinished( int, bool ) ) );
 }
 
 
@@ -207,7 +207,7 @@ Reader::loginFinished( int /* id */, bool error )
 {
     DEBUG_BLOCK
     ContentFetcher* http = (ContentFetcher*) sender();
-    disconnect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( loginFinished( int, bool ) ) );
+    disconnect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( loginFinished( int, bool ) ) );
     if( error )
     {
         http->deleteLater();
@@ -217,7 +217,7 @@ Reader::loginFinished( int /* id */, bool error )
 
     m_sessionId = loginResults["mlog"].asList()[0].asMap()["mlid"].asList()[0].asInt();
     m_loginString = "session-id=" + TQString::number( m_sessionId );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( updateFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( updateFinished( int, bool ) ) );
     http->getDaap( "/update?" + m_loginString );
 }
 
@@ -226,7 +226,7 @@ Reader::updateFinished( int /*id*/, bool error )
 {
     DEBUG_BLOCK
     ContentFetcher* http = (ContentFetcher*) sender();
-    disconnect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( updateFinished( int, bool ) ) );
+    disconnect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( updateFinished( int, bool ) ) );
     if( error )
     {
         http->deleteLater();
@@ -238,7 +238,7 @@ Reader::updateFinished( int /*id*/, bool error )
     m_loginString = m_loginString + "&revision-number="  +
             TQString::number( updateResults["mupd"].asList()[0].asMap()["musr"].asList()[0].asInt() );
 
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( databaseIdFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( databaseIdFinished( int, bool ) ) );
     http->getDaap( "/databases?" + m_loginString );
 
 }
@@ -247,7 +247,7 @@ void
 Reader::databaseIdFinished( int /*id*/, bool error )
 {
     ContentFetcher* http = (ContentFetcher*) sender();
-    disconnect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( databaseIdFinished( int, bool ) ) );
+    disconnect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( databaseIdFinished( int, bool ) ) );
     if( error )
     {
         http->deleteLater();
@@ -256,7 +256,7 @@ Reader::databaseIdFinished( int /*id*/, bool error )
 
     TQStringVariantMap dbIdResults = parse( http->results(), 0, true );
     m_databaseId = TQString::number( dbIdResults["avdb"].asList()[0].asMap()["mlcl"].asList()[0].asMap()["mlit"].asList()[0].asMap()["miid"].asList()[0].asInt() );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( songListFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( songListFinished( int, bool ) ) );
     http->getDaap( TQString("/databases/%1/items?type=music&meta=dmap.itemid,dmap.itemname,daap.songformat,daap.songartist,daap.songalbum,daap.songtime,daap.songtracknumber,daap.songcomment,daap.songyear,daap.songgenre&%2")
                 .arg( m_databaseId, m_loginString ) );
 
@@ -266,7 +266,7 @@ void
 Reader::songListFinished( int /*id*/, bool error )
 {
     ContentFetcher* http = (ContentFetcher*) sender();
-    disconnect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( songListFinished( int, bool ) ) );
+    disconnect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( songListFinished( int, bool ) ) );
     if( error )
     {
         http->deleteLater();
