@@ -38,7 +38,7 @@ DaapServer::DaapServer(TQObject* parent, char* name)
         return;
     }
 
-    connect( m_server, TQT_SIGNAL( readReady( KProcIO* ) ), this, TQT_SLOT( readSql() ) );
+    connect( m_server, TQ_SIGNAL( readReady( KProcIO* ) ), this, TQ_SLOT( readSql() ) );
 }
 
 DaapServer::~DaapServer()
