@@ -33,7 +33,7 @@ class TransferDialog;
 
 class IfpMediaDevice : public MediaDevice
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
