@@ -41,7 +41,7 @@ AMAROK_EXPORT_PLUGIN( NjbMediaDevice )
 #include <kdebug.h>
 #include <tdefiledialog.h>
 #include <kiconloader.h>       //smallIcon
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdelocale.h>
 #include <tdemessagebox.h>
 #include <tdepopupmenu.h>
@@ -380,7 +380,7 @@ NjbMediaDevice::downloadToCollection()
     TQPtrList<MediaItem> items;
     m_view->getSelectedLeaves( 0, &items );
 
-    KTempDir tempdir( TQString::null ); // Default prefix is fine with us
+    KTempDir tempdir; // Default prefix is fine with us
     tempdir.setAutoDelete( true ); // We don't need it once the work is done.
     TQString path = tempdir.name(), filepath;
     KURL::List urls;
