@@ -36,9 +36,9 @@ MediaDeviceManager* MediaDeviceManager::instance()
 MediaDeviceManager::MediaDeviceManager()
 {
     DEBUG_BLOCK
-    connect( DeviceManager::instance(), TQT_SIGNAL( mediumAdded( const Medium*, TQString ) ), TQT_SLOT( slotMediumAdded( const Medium*, TQString ) ) );
-    connect( DeviceManager::instance(), TQT_SIGNAL( mediumChanged( const Medium*, TQString ) ), TQT_SLOT( slotMediumChanged( const Medium*, TQString ) ) );
-    connect( DeviceManager::instance(), TQT_SIGNAL( mediumRemoved( const Medium*, TQString ) ), TQT_SLOT( slotMediumRemoved( const Medium*, TQString ) ) );
+    connect( DeviceManager::instance(), TQ_SIGNAL( mediumAdded( const Medium*, TQString ) ), TQ_SLOT( slotMediumAdded( const Medium*, TQString ) ) );
+    connect( DeviceManager::instance(), TQ_SIGNAL( mediumChanged( const Medium*, TQString ) ), TQ_SLOT( slotMediumChanged( const Medium*, TQString ) ) );
+    connect( DeviceManager::instance(), TQ_SIGNAL( mediumRemoved( const Medium*, TQString ) ), TQ_SLOT( slotMediumRemoved( const Medium*, TQString ) ) );
     Medium::List mediums = DeviceManager::instance()->getDeviceList();
     foreachType( Medium::List, mediums )
     {
@@ -47,7 +47,7 @@ MediaDeviceManager::MediaDeviceManager()
     if( !mediums.count() )
     {
         debug() << "DeviceManager didn't return any devices, we are probably running on a non-KDE system. Trying to reinit media devices later" << endl;
-        TQTimer::singleShot( 4000, this, TQT_SLOT( reinitDevices() ) );
+        TQTimer::singleShot( 4000, this, TQ_SLOT( reinitDevices() ) );
     }
     //load manual devices
     TQStringList manualDevices;
