@@ -30,7 +30,7 @@ class MediaDeviceManager : public TQObject
     //static const uint APPLE = 1;
     //static const uint IFP = 2;
 
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         MediaDeviceManager();
