@@ -189,7 +189,7 @@ void MultiTabBarInternal::showTabSelectionMenu(TQPoint pos)
 
 void MultiTabBarInternal::mousePressEvent( TQMouseEvent *ev )
 {
-    if ( ev->button() != Qt::RightButton ){
+    if ( ev->button() != TQt::RightButton ){
         ev->ignore();
         return;
     }
@@ -375,7 +375,7 @@ bool MultiTabBarInternal::eventFilter( TQObject *, TQEvent *e )
 
     //PATCH by markey: Allow switching of tabs with mouse wheel
     if ( e->type() == TQEvent::Wheel ) {
-        TQWheelEvent* event = TQT_TQWHEELEVENT( e );
+        TQWheelEvent* event = static_cast<TQWheelEvent*>( e );
         const int delta = event->delta() / 120;
 
         // Determine which tab is currently active
@@ -526,9 +526,9 @@ MultiTabBarButton::MultiTabBarButton( const TQPixmap& pic, const TQString& text,
     setFixedWidth( 24 );
 
 //     TQToolTip::add( this, text );  // Deactivated cause it's annoying
-    connect( this, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotClicked() ) );
-    connect( m_animTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotAnimTimer() ) );
-    connect( m_dragSwitchTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotDragSwitchTimer() ) );
+    connect( this, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotClicked() ) );
+    connect( m_animTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAnimTimer() ) );
+    connect( m_dragSwitchTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotDragSwitchTimer() ) );
 }
 
 MultiTabBarButton::MultiTabBarButton( const TQString& text, TQPopupMenu *popup,
@@ -549,9 +549,9 @@ MultiTabBarButton::MultiTabBarButton( const TQString& text, TQPopupMenu *popup,
     m_id = id;
 //     TQToolTip::add( this, text );
 
-    connect( this, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotClicked() ) );
-    connect( m_animTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotAnimTimer() ) );
-    connect( m_dragSwitchTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotDragSwitchTimer() ) );
+    connect( this, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotClicked() ) );
+    connect( m_animTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAnimTimer() ) );
+    connect( m_dragSwitchTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotDragSwitchTimer() ) );
 }
 
 MultiTabBarButton::~MultiTabBarButton()
@@ -714,7 +714,7 @@ TQSize MultiTabBarButton::sizeHint() const
 //             h = ( parentWidget()->width() - 3 ) / NUM_TABS;
 //     }
 
-    return ( style().tqsizeFromContents( TQStyle::CT_ToolButton, this, TQSize( w, h ) ).
+    return ( style().sizeFromContents( TQStyle::CT_ToolButton, this, TQSize( w, h ) ).
              expandedTo( TQApplication::globalStrut() ) );
 }
 
