@@ -174,7 +174,7 @@ PrettyPopupMenu::paintEvent( TQPaintEvent* e )
 
     drawContents( &p );
 
-    style().tqdrawPrimitive( TQStyle::PE_PanelPopup, &p,
+    style().drawPrimitive( TQStyle::PE_PanelPopup, &p,
                            TQRect( 0, 0, width(), height() ),
                            colorGroup(), TQStyle::Style_Default,
                            TQStyleOption( frameWidth(), 0 ) );
