@@ -66,7 +66,7 @@ RefreshImages::RefreshImages()
         it++; //iterate to the next set
 
         m_jobInfo[md5sum] = JobInfo( asin, locale, it == end );
-        connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), TQT_SLOT( finishedXmlFetch( TDEIO::Job* ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ), TQ_SLOT( finishedXmlFetch( TDEIO::Job* ) ) );
     }
 }
 
@@ -123,7 +123,7 @@ RefreshImages::finishedXmlFetch( TDEIO::Job* xmlJob ) //SLOT
        .namedItem( "Items" )
        .namedItem( "Item" )
        .namedItem( "DetailPageURL" ).firstChild().toText().data();
-    connect( imageJob, TQT_SIGNAL( result(TDEIO::Job*) ), TQT_SLOT( finishedImageFetch(TDEIO::Job*) ) );
+    connect( imageJob, TQ_SIGNAL( result(TDEIO::Job*) ), TQ_SLOT( finishedImageFetch(TDEIO::Job*) ) );
 }
 
 void RefreshImages::finishedImageFetch(TDEIO::Job* imageJob)
