@@ -50,7 +50,7 @@ class ScanController : public JobBase, public TQXmlDefaultHandler
 class ScanController : public ThreadManager::DependentJob, public TQXmlDefaultHandler
 #endif // Q_MOC_RUN
 {
-    Q_OBJECT
+    TQ_OBJECT
     
 
     public:
