@@ -179,17 +179,17 @@ ScriptManager::ScriptManager( TQWidget *parent, const char *name )
     m_scoreCategory    ->setOpen( config->readBoolEntry( "Score category State" ) );
     m_transcodeCategory->setOpen( config->readBoolEntry( "Transcode category open" ) );
 
-    connect( m_gui->listView, TQT_SIGNAL( currentChanged( TQListViewItem* ) ), TQT_SLOT( slotCurrentChanged( TQListViewItem* ) ) );
-    connect( m_gui->listView, TQT_SIGNAL( doubleClicked ( TQListViewItem*, const TQPoint&, int ) ), TQT_SLOT( slotRunScript() ) );
-    connect( m_gui->listView, TQT_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ), TQT_SLOT( slotShowContextMenu( TQListViewItem*, const TQPoint& ) ) );
+    connect( m_gui->listView, TQ_SIGNAL( currentChanged( TQListViewItem* ) ), TQ_SLOT( slotCurrentChanged( TQListViewItem* ) ) );
+    connect( m_gui->listView, TQ_SIGNAL( doubleClicked ( TQListViewItem*, const TQPoint&, int ) ), TQ_SLOT( slotRunScript() ) );
+    connect( m_gui->listView, TQ_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ), TQ_SLOT( slotShowContextMenu( TQListViewItem*, const TQPoint& ) ) );
 
-    connect( m_gui->installButton,   TQT_SIGNAL( clicked() ), TQT_SLOT( slotInstallScript() ) );
-    connect( m_gui->retrieveButton,  TQT_SIGNAL( clicked() ), TQT_SLOT( slotRetrieveScript() ) );
-    connect( m_gui->uninstallButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotUninstallScript() ) );
-    connect( m_gui->runButton,       TQT_SIGNAL( clicked() ), TQT_SLOT( slotRunScript() ) );
-    connect( m_gui->stopButton,      TQT_SIGNAL( clicked() ), TQT_SLOT( slotStopScript() ) );
-    connect( m_gui->configureButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotConfigureScript() ) );
-    connect( m_gui->aboutButton,     TQT_SIGNAL( clicked() ), TQT_SLOT( slotAboutScript() ) );
+    connect( m_gui->installButton,   TQ_SIGNAL( clicked() ), TQ_SLOT( slotInstallScript() ) );
+    connect( m_gui->retrieveButton,  TQ_SIGNAL( clicked() ), TQ_SLOT( slotRetrieveScript() ) );
+    connect( m_gui->uninstallButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotUninstallScript() ) );
+    connect( m_gui->runButton,       TQ_SIGNAL( clicked() ), TQ_SLOT( slotRunScript() ) );
+    connect( m_gui->stopButton,      TQ_SIGNAL( clicked() ), TQ_SLOT( slotStopScript() ) );
+    connect( m_gui->configureButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotConfigureScript() ) );
+    connect( m_gui->aboutButton,     TQ_SIGNAL( clicked() ), TQ_SLOT( slotAboutScript() ) );
 
     m_gui->installButton  ->setIconSet( SmallIconSet( Amarok::icon( "files" ) ) );
     m_gui->retrieveButton ->setIconSet( SmallIconSet( Amarok::icon( "download" ) ) );
@@ -203,10 +203,10 @@ ScriptManager::ScriptManager( TQWidget *parent, const char *name )
     setMinimumSize( kMax( 350, sz.width() ), kMax( 250, sz.height() ) );
     resize( sizeHint() );
 
-    connect( this, TQT_SIGNAL(lyricsScriptChanged()), ContextBrowser::instance(), TQT_SLOT( lyricsScriptChanged() ) );
+    connect( this, TQ_SIGNAL(lyricsScriptChanged()), ContextBrowser::instance(), TQ_SLOT( lyricsScriptChanged() ) );
 
     // Delay this call via eventloop, because it's a bit slow and would block
-    TQTimer::singleShot( 0, this, TQT_SLOT( findScripts() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( findScripts() ) );
 }
 
 
@@ -500,7 +500,7 @@ ScriptManager::slotRetrieveScript()
     d->setType( "amarok/script" );
     // you have to do this by hand when providing your own Engine
     KNS::ProviderLoader *p = new KNS::ProviderLoader( this );
-    TQObject::connect( p, TQT_SIGNAL( providersLoaded(Provider::List*) ), d, TQT_SLOT( slotProviders (Provider::List *) ) );
+    TQObject::connect( p, TQ_SIGNAL( providersLoaded(Provider::List*) ), d, TQ_SLOT( slotProviders (Provider::List *) ) );
     p->load( "amarok script", "https://www.trinitydesktop.org/ocs/providers.xml" );
 
     d->exec();
@@ -570,14 +570,14 @@ ScriptManager::slotRunScript( bool silent )
     TQListViewItem* const li = m_gui->listView->currentItem();
     const TQString name = li->text( 0 );
 
-    if( m_scripts[name].type == "lyrics" && lyricsScriptRunning() != TQString() ) {
+    if( m_scripts[name].type == "lyrics" && !lyricsScriptRunning().isEmpty() ) {
         if( !silent )
             KMessageBox::sorry( 0, i18n( "Another lyrics script is already running. "
                                          "You may only run one lyrics script at a time." ) );
         return false;
     }
 
-    if( m_scripts[name].type == "transcode" && transcodeScriptRunning() != TQString() ) {
+    if( m_scripts[name].type == "transcode" && !transcodeScriptRunning().isEmpty() ) {
         if( !silent )
             KMessageBox::sorry( 0, i18n( "Another transcode script is already running. "
                                          "You may only run one transcode script at a time." ) );
@@ -593,9 +593,9 @@ ScriptManager::slotRunScript( bool silent )
     *script << url.path();
     script->setWorkingDirectory( Amarok::saveLocation( "scripts-data/" ) );
 
-    connect( script, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), TQT_SLOT( slotReceivedStderr( TDEProcess*, char*, int ) ) );
-    connect( script, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), TQT_SLOT( slotReceivedStdout( TDEProcess*, char*, int ) ) );
-    connect( script, TQT_SIGNAL( processExited( TDEProcess* ) ), TQT_SLOT( scriptFinished( TDEProcess* ) ) );
+    connect( script, TQ_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), TQ_SLOT( slotReceivedStderr( TDEProcess*, char*, int ) ) );
+    connect( script, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), TQ_SLOT( slotReceivedStdout( TDEProcess*, char*, int ) ) );
+    connect( script, TQ_SIGNAL( processExited( TDEProcess* ) ), TQ_SLOT( scriptFinished( TDEProcess* ) ) );
 
     if( script->start( TDEProcess::NotifyOnExit ) )
     {
@@ -677,7 +677,7 @@ ScriptManager::slotAboutScript()
     about->setCaption( kapp->makeStdCaption( i18n( "About %1" ).arg( name ) ) );
     about->setProduct( "", "", "", "" );
     // Get rid of the confusing KDE version text
-    TQLabel* product = static_cast<TQLabel*>( TQT_TQWIDGET(about->mainWidget()->child( "version" )) );
+    TQLabel* product = static_cast<TQLabel*>( about->mainWidget()->child( "version" ) );
     if( product ) product->setText( i18n( "%1 Amarok Script" ).arg( name ) );
 
     about->addTextPage( i18n( "About" ), readme.readAll(), true );
