@@ -42,7 +42,7 @@ private:
  */
 class EqualizerCanvasView : public TQCanvasView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     EqualizerCanvasView(TQWidget *parent, const char *name);
@@ -64,7 +64,7 @@ private:
 
 class CallAmarok : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CallAmarok(TQObject* parent, const char *name,
