@@ -28,7 +28,7 @@
 */
 class EqualizerDialog : public TQDialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     EqualizerDialog();
