@@ -146,7 +146,7 @@ class Test( TQApplication ):
 
         self.dia = ConfigDialog()
         self.dia.show()
-        self.connect( self.dia, SIGNAL( "destroyed()" ), self.readSettings )
+        self.connect( self.dia, TQ_SIGNAL( "destroyed()" ), self.readSettings )
 
     def engineStatePlay( self ):
         """ Called when Engine state changes to Play """
