@@ -101,9 +101,9 @@ Vis::SocketServer::newConnection( int sockfd )
 /// @class Vis::SocketNotifier
 
 Vis::SocketNotifier::SocketNotifier( int sockfd )
-        : TQSocketNotifier( sockfd, TQSocketNotifier::Read, TQT_TQOBJECT(this) )
+        : TQSocketNotifier( sockfd, TQSocketNotifier::Read, this )
 {
-    connect( this, TQT_SIGNAL(activated( int )), TQT_SLOT(request( int )) );
+    connect( this, TQ_SIGNAL(activated( int )), TQ_SLOT(request( int )) );
 }
 
 void
@@ -150,12 +150,12 @@ Vis::Selector::instance()
 
     debug() << bool(o == 0) << endl;
 
-    return o ? static_cast<Selector*>( TQT_TQWIDGET(o) ) : new Selector( parent );
+    return o ? static_cast<Selector*>( o ) : new Selector( parent );
 }
 
 Vis::Selector::Selector( TQWidget *parent )
         : TQListView( parent, "Vis::Selector::instance", TQt::WType_Dialog )
-        , m_server( new SocketServer( TQT_TQOBJECT(this) ) )
+        , m_server( new SocketServer( this ) )
 {
     Amarok::OverrideCursor waitcursor;
 
@@ -173,8 +173,8 @@ Vis::Selector::Selector( TQWidget *parent )
     reinterpret_cast<TQWidget*>(header())->hide();
 
 
-     connect( this, TQT_SIGNAL(contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
-              this, TQT_SLOT(rightButton( TQListViewItem*, const TQPoint&, int )) );
+     connect( this, TQ_SIGNAL(contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
+              this, TQ_SLOT(rightButton( TQListViewItem*, const TQPoint&, int )) );
 
     // Can I get a pointer to the data section of a TQCString?
     char str[4096];
@@ -286,9 +286,9 @@ Vis::Selector::Item::stateChange( bool ) //SLOT
                << Selector::instance()->m_server->path()
                << text( 0 );
 
-        connect( m_proc, TQT_SIGNAL(processExited( TDEProcess* )), listView(), TQT_SLOT(processExited( TDEProcess* )) );
+        connect( m_proc, TQ_SIGNAL(processExited( TDEProcess* )), listView(), TQ_SLOT(processExited( TDEProcess* )) );
         // Shouldn't be necessary, but make visualizations work again when running with amarok binary
-        connect( m_proc, TQT_SIGNAL(receivedStdout (TDEProcess*, char*, int ) ), listView(), TQT_SLOT(receivedStdout (TDEProcess*, char*, int ) ) );
+        connect( m_proc, TQ_SIGNAL(receivedStdout (TDEProcess*, char*, int ) ), listView(), TQ_SLOT(receivedStdout (TDEProcess*, char*, int ) ) );
         debug() << "Starting visualization..\n";
         if( m_proc->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
             break;
