@@ -29,7 +29,7 @@ class TrackPickerDialogBase;
 
 class TrackPickerDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 signals:
