@@ -42,7 +42,7 @@ TransferDialog::TransferDialog( MediaDevice *mdev )
 
     TQString transferDir = mdev->getTransferDir();
 
-    TQGroupBox *location = new TQGroupBox( 1, Qt::Vertical, i18n( "Music Location" ), vbox );
+    TQGroupBox *location = new TQGroupBox( 1, TQt::Vertical, i18n( "Music Location" ), vbox );
 
     new TQLabel( i18n( "Your music will be transferred to:\n%1" )
                     .arg( transferDir ), location );
@@ -57,7 +57,7 @@ TransferDialog::TransferDialog( MediaDevice *mdev )
                       "a variety of ways. Each grouping will create\n"
                       "directories based upon the specified criteria.\n"), vbox );
 
-    TQGroupBox *sorting = new TQGroupBox( 6, Qt::Vertical, i18n( "Groupings" ), vbox );
+    TQGroupBox *sorting = new TQGroupBox( 6, TQt::Vertical, i18n( "Groupings" ), vbox );
     m_label1 = new TQLabel( i18n( "Select first grouping:\n" ), sorting );
     m_sort1  = new KComboBox( sorting );
     m_label2 = new TQLabel( i18n( "Select second grouping:\n" ), sorting );
@@ -89,8 +89,8 @@ TransferDialog::TransferDialog( MediaDevice *mdev )
     m_label3->setDisabled( m_sort2->currentItem() == 0 );
     m_sort3->setDisabled( m_sort2->currentItem() == 0 );
 
-    connect( m_sort1, TQT_SIGNAL( activated(int) ), TQT_SLOT( sort1_activated(int)) );
-    connect( m_sort2, TQT_SIGNAL( activated(int) ), TQT_SLOT( sort2_activated(int)) );
+    connect( m_sort1, TQ_SIGNAL( activated(int) ), TQ_SLOT( sort1_activated(int)) );
+    connect( m_sort2, TQ_SIGNAL( activated(int) ), TQ_SLOT( sort2_activated(int)) );
 
     TQVBox *vbox3 = new TQVBox( vbox );
     TQSpacerItem *spacer2 = new TQSpacerItem( 0, 25 );
@@ -98,12 +98,12 @@ TransferDialog::TransferDialog( MediaDevice *mdev )
     if( vlayout2 )
         vlayout2->addItem( spacer2 );
 
-    TQGroupBox *options = new TQGroupBox( 6, Qt::Vertical, i18n( "Options" ), vbox );
+    TQGroupBox *options = new TQGroupBox( 6, TQt::Vertical, i18n( "Options" ), vbox );
 
     TQCheckBox *convertSpaces = new TQCheckBox( i18n( "Convert spaces to underscores" ), options );
     convertSpaces->setChecked( mdev->getSpacesToUnderscores() );
 
-    connect( convertSpaces, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( convertSpaces_toggled(bool) ) );
+    connect( convertSpaces, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( convertSpaces_toggled(bool) ) );
 }
 
 void
